# -*- coding: utf-8 -*-

from dp_tornado.engine.controller import Controller as dpController


class ContactController(dpController):
    def get(self, param1=None, param2=None):
        server_version = self.config.server.version.master

        self.finish('/main/contact with %s, %s (server ver. %s)' % (param1, param2, server_version))



# -*- coding: utf-8 -*-


from dp_tornado.engine.helper import Helper as dpHelper

import re

regex = re.compile(
    r'^(?:http|ftp)s?://'
    r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|'
    r'localhost|'
    r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})'
    r'(?::\d+)?'
    r'(?:/?|[/?]\S+)$', re.IGNORECASE)


class UrlHelper(dpHelper):
    def validate(self, e):
        return True if re.match(regex, e) else False



# -*- coding: utf-8 -*-


import tornado.escape


def trim(c, t):
    return t.strip()


def nl2br(c, t, escape=True):
    if not t:
        return ''

    t = tornado.escape.xhtml_escape(t) if escape else t
    return t.replace('\r\n', '<br />').replace('\r', '<br />').replace('\n', '<br />')


def truncate(c, t, l, s='..'):
    if len(t) > l:
        return '%s%s' % (t[0:l], s)

    return t


def yyyymmdd(c, t, s='.'):
    return c.helper.datetime.yyyymmdd(s=s, d=t)


def mmdd(c, t, s='.'):
    return c.helper.datetime.mmdd(s=s, d=t)


def hhiiss(c, t, s=':'):
    return c.helper.datetime.hhiiss(s=s, d=t)


def hhii(c, t, s=':'):
    return c.helper.datetime.hhii(s=s, d=t)


def weekday(c, t):
    return c.helper.datetime.weekday(d=t)


def request_uri(c, s=False, d=' ', p='_', e=False, q=True):
    r = ('%s%s' % (d, p)).join(c.request.uri.split('/')).strip() if s else c.request.uri
    r = r if q else r.split('?')[0:1][0]
    return c.helper.url.quote(r) if e else r


def i18n(c):
    return c.helper.i18n


def c(c):
    return c


def get(c, arg, default=None):
    uri = c.helper.url.parse(c.request.uri)
    return uri.query[arg] if uri.query and arg in uri.query else default


def number_format(c, val):
    return "{:,}".format(val)


def prefix(c, static_url, query=None, combine_request_query=False, prefix=None, prefix_alternative=None):
    if combine_request_query:
        uri = c.helper.url.parse(c.request.uri)

        if query and isinstance(query, dict):
            query = dict(uri.query, **query)

        elif not query:
            query = uri.query

    if query and isinstance(query, dict):
        uri = c.helper.url.parse(static_url)

        for k in query.keys():
            v = query[k]

            if v is None and k in uri.query:
                del uri.query[k]
            elif v is not None:
                uri.query[k] = v

        static_url = c.helper.url.build(uri.path, uri.query)

    if prefix or 'X-Proxy-Prefix' in c.request.headers:
        p = prefix_alternative or prefix or c.request.headers['X-Proxy-Prefix']
        p = p[:-1] if p.endswith('/') else p

        if static_url.startswith(p):
            return static_url[len(p):]

        return static_url
    else:
        return static_url



# -*- coding: utf-8 -*-


import tornado.web

from dp_tornado.engine.engine import Engine as dpEngine


class PrefixURL(tornado.web.UIModule, dpEngine):
    def render(self, static_url, query=None, combine_request_query=False, prefix=None, prefix_alternative=None):
        if combine_request_query:
            uri = self.helper.url.parse(self.handler.request.uri)

            if query and isinstance(query, dict):
                query = dict(uri.query, **query)

            elif not query:
                query = uri.query

        if query and isinstance(query, dict):
            uri = self.helper.url.parse(static_url)

            for k in query.keys():
                v = query[k]

                if v is None and k in uri.query:
                    del uri.query[k]
                elif v is not None:
                    uri.query[k] = v

            static_url = self.helper.url.build(uri.path, uri.query)

        if prefix or 'X-Proxy-Prefix' in self.handler.request.headers:
            prefix = prefix_alternative or prefix or self.handler.request.headers['X-Proxy-Prefix']
            prefix = prefix[:-1] if prefix.endswith('/') else prefix

            if static_url.startswith(prefix):
                return static_url[len(prefix):]

            return static_url
        else:
            return static_url



import os

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

description = 'MVC Web Application Framework with Tornado.'

if os.path.exists('README.md'):
    long_description = open('README.md').read()
else:
    long_description = description

setup(
    name='dp-tornado',
    version="0.5.0",
    url='http://github.com/why2pac/dp-tornado',
    license='MIT',
    author='YoungYong Park',
    author_email='youngyongpark@gmail.com',
    maintainer='YoungYong Park',
    maintainer_email='youngyongpark@gmail.com',
    description=description,
    long_description=long_description,
    packages=[
        'dp_tornado',
        'dp_tornado/engine',
        'dp_tornado/engine/driver',
        'dp_tornado/engine/scheduler',
        'dp_tornado/engine/plugin',
        'dp_tornado/helper',
        'dp_tornado/helper/archive',
        'dp_tornado/helper/aws',
        'dp_tornado/helper/i18n',
        'dp_tornado/helper/image',
        'dp_tornado/helper/image/resize',
        'dp_tornado/helper/validator'],
    include_package_data=True,
    install_requires=[
        'tornado==4.3',
        'redis==2.10.3',
        'requests==2.8.1',
        'croniter==0.3.8',
        'boto==2.38.0',
        'SQLAlchemy==1.0.9',
        'futures==3.0.3',
        'Pillow==3.1.1'
    ],
    keywords=['MVC', 'Web Application Framework'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4'
    ],
)



# -*- coding: utf-8 -*-


from .sqlite_driver import SqliteCacheDriver as dpSqliteCacheDriver


class MemoryCacheDriver(dpSqliteCacheDriver):
    @staticmethod
    def getpool(config_dsn=None, host=None, port=None, database=None, user=None, password=None):
        driver = MemoryCacheDriver(config_dsn=config_dsn)
        driver._config_dsn = config_dsn
        return driver

    def _table_name(self, config_dsn):
        return config_dsn.replace('/', '_').replace('.', '_')
